body	{
	font-size: 12px; font-family: "DejaVu Sans Mono", monospace; font-style: normal; font-weight: normal; margin: 0;
	background: white; background-color: white
	}

#Chat  { padding-top: 80px; margin: 4px; overflow: hidden }

#Header { background: url("../images/background2.png") repeat-x right top; position: fixed; z-index: 100; top: 0; right: 0; left: 0; height: 80px; border-bottom: 0 none }

.imageContainer  { display: none; }

.chatName  { color: #3d4f51; font-size: 14px; font-weight: bold; text-align: center; position: relative; margin-left: 2px; margin-right: 5px }

.headerContainer  { padding: 1px 1px; position: relative; border-style: dotted none; border-width: 2px medium; border-color: #666 black }

.container  { margin-bottom: 2px;  overflow: auto; }

a:link  { color: #5099ff }
a:visited  { color: #5099ff }
a:hover  { color: #82b6ff }

.messageTime  { color: #3d3d3d; font-size: 10px; font-weight: normal; text-align: left; position: relative; z-index: 60; top: 0px; float: left; margin-right: 4px }

.Message  { color: black; font-style: normal; font-weight: normal; position: relative; margin-left: 2px; margin-right: 5px }

.pastMessage  { color: #a0a3a6; font-style: normal; font-weight: normal }

.statusContainer  { margin-bottom: 2px }

.statusTime  { color: #2d425f; font-size: 10px; font-weight: bold; top: 0px; text-align: right; margin-right: 5px; position: relative; width: 150px; float: left }

.statusMessage  { color: #4d6581; font-size: 12px; font-weight: bold; position: relative; right: 5px }

.buddy  { color: #5099ff; font-weight: bold; text-align: left; display: block; position: relative; margin-left: 2px }

.user  { color: gray; font-weight: bold; text-align: left; display: block; position: relative; margin-left: 2px }

.pastBuddy  { color: #7ab382; font-size: 11px; font-weight: bold; text-align: left; position: relative }

.pastUser  { color: #7b95b4; font-size: 11px; font-weight: bold; text-align: left; position: relative }
