@import url(../main.css);

body	{
	font-size: 12px; font-family: "DejaVu Sans Mono", monospace; font-style: normal; font-weight: normal; margin: 0;
	background-color: black
	}

.imageContainer  { margin: 4px 4px 4px 4px; display: block }
.buddyIcon  { width: 48px; float: right; border-style: dotted none; border-width: 2px medium; border-color: #666 white }