<!DOCTYPE kpartgui>
<kpartgui version="4" name="kopete_yahoo_conference">
	<MenuBar>
		<Menu noMerge="1" name="file">
                        <text>&amp;Chat</text>
			<Action name="yahooInvite" />
		</Menu>
	</MenuBar>

</kpartgui>

